use std::collections::HashMap;

fn spawn_points(pattern: &str) -> Vec<(i32, i32)> {
    
    let mut pts = vec![];

    let digits = pattern
        .chars()
        .filter(|x| x.is_numeric())
        .collect::<String>()
        .parse()
        .unwrap();

    let direction: String = pattern.chars().filter(|x| !x.is_numeric()).collect();

    match direction.as_ref() {
        "R" => {
            for d in 0..digits {
                pts.push((0,1));
            }
        }
        "L" => {
            for d in 0..digits {
                pts.push((0,-1));
            }
        }
        "U" => {
            for d in 0..digits {
                pts.push((1,0));
            }
        }
        "D" => {
            for d in 0..digits {
                pts.push((-1,0));
            }
        }
        _ => {}

    }
    pts

}


fn run_instruction_set(instructions: Vec<String>, grid: &mut HashMap<(i32,i32), i32>) -> Option<i32>{
    let mut cursor = (0,0);
    let mut closest = std::i32::MAX; // largest i32 ever
    for instruction in instructions {
        
        for pt in spawn_points(&instruction) {
            // println!("Marching to {:?}", cursor);
            if let Some(occupied_pt) = grid.get(&cursor) {
                println!("Point present @{:?}", cursor);
                let dist = cursor.0.abs()+cursor.1.abs();
                if dist < closest && dist > 0 {
                    closest = dist;
                }
                grid.insert(cursor, occupied_pt + 1);
            } else {
                grid.insert(cursor, 0);
            }
            cursor.0 += pt.0;
            cursor.1 += pt.1;

        }


    }

    match closest {
        std::i32::MAX => None,
        _ => Some(closest)
    }
}

fn solve() {
    // R75,D30,R83,U83,L12,D49,R71,U7,L72

    // Hashmap that has a 2d point as key and a vec for wire indices
    let mut grid: HashMap<(i32,i32), i32> = HashMap::new();

    let w1s = include_str!("wire1");
    let w2s = include_str!("wire2");

    let w1: Vec<String> = w1s.split(",").map(|s| s.to_string()).collect();
    let w2: Vec<String> = w2s.split(",").map(|s| s.to_string()).collect();

    run_instruction_set(w1, &mut grid);
    dbg!(run_instruction_set(w2, &mut grid));

    // dbg!(grid);

}





pub fn main() {
    solve();
}